@@ -1,3 +1,20 @@
+coda_wrapper <- function(dbr_obj, coda_function, ...) {
+  smp <- dbr_obj$est@learners[[2]]@est$smp
+  estimate_left_buffer <- dbr_obj$control$estimate_left_buffer
+  estimate_right_buffer <- dbr_obj$control$estimate_right_buffer
+  smp_ncol <- ncol(smp)
+  idx <- 3:smp_ncol
+  if (estimate_right_buffer) idx <- c(2, idx)
+  if (estimate_left_buffer) idx <- c(1, idx)
+  
+  mcmc_obj <- mcmc(
+    data = smp[, idx]
+    , start = dbr_obj$control$nburnin
+    , end = dbr_obj$control$nsmp
+    , thin = 1)
+  coda_function(mcmc_obj, ...)
+}
+
 get_intervals <- function(uniqueVals) {
   uniqueVals <- sort(uniqueVals)
   0.5 * (uniqueVals[1:(length(uniqueVals) - 1)] + uniqueVals[-1])
